@@ -10,14 +10,14 @@ from __future__ import absolute_import
 
 from thoonk import Pubsub
 
-from redis import exceptions as client_exceptions
+from redis import RedisError
 
 from nydus.db.backends import BaseConnection
 
 
 class Thoonk(BaseConnection):
     # Exceptions that can be retried by this backend
-    retryable_exceptions = client_exceptions
+    retryable_exceptions = frozenset([RedisError])
     supports_pipelines = False
 
     def __init__(self, host='localhost', port=6379, db=0, timeout=None, listen=False, **options):
