@@ -6,22 +6,40 @@ nydus.db.base
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
+__all__ = ('LazyConnectionHandler', 'create_cluster', 'Cluster')
+
 from collections import defaultdict
-from nydus.db.routers import BaseRouter
+from nydus.db.routers import BaseRouter, routing_params
 from nydus.utils import import_string, ThreadPool
 
 
+def apply_defaults(host, defaults):
+    for key, value in defaults.iteritems():
+        if key not in host:
+            host[key] = value
+    return host
+
+
 def create_cluster(settings):
     """
-    redis = create_cluster({
-        'engine': 'nydus.db.backends.redis.Redis',
-        'router': 'nydus.db.routers.redis.PartitionRouter',
-        'hosts': {
-            0: {'db': 0},
-            1: {'db': 1},
-            2: {'db': 2},
-        }
-    })
+    Creates a new Nydus cluster from the given settings.
+
+    :param settings: Dictionary of the cluster settings.
+    :returns: Configured instance of ``nydus.db.base.Cluster``.
+
+    >>> redis = create_cluster({
+    >>>     'engine': 'nydus.db.backends.redis.Redis',
+    >>>     'router': 'nydus.db.routers.redis.PartitionRouter',
+    >>>     'defaults': {
+    >>>         'host': 'localhost',
+    >>>         'port': 6379,
+    >>>     },
+    >>>     'hosts': {
+    >>>         0: {'db': 0},
+    >>>         1: {'db': 1},
+    >>>         2: {'db': 2},
+    >>>     }
+    >>> })
     """
     # Pull in our client
     if isinstance(settings['engine'], basestring):
@@ -38,11 +56,13 @@ def create_cluster(settings):
     else:
         router = BaseRouter
 
+    defaults = settings.get('defaults', {})
+
     # Build the connection cluster
     return Cluster(
         router=router,
         hosts=dict(
-            (conn_number, Conn(num=conn_number, **host_settings))
+            (conn_number, Conn(num=conn_number, **apply_defaults(host_settings, defaults)))
             for conn_number, host_settings
             in settings['hosts'].iteritems()
         ),
@@ -58,7 +78,7 @@ class Cluster(object):
 
     def __init__(self, hosts, router=BaseRouter, max_connection_retries=20):
         self.hosts = hosts
-        self.router = router()
+        self.router = router(self)
         self.max_connection_retries = max_connection_retries
 
     def __len__(self):
@@ -78,7 +98,7 @@ class Cluster(object):
             yield name
 
     def _execute(self, attr, args, kwargs):
-        connections = self._connections_for(attr, *args, **kwargs)
+        connections = self._connections_for(attr, args=args, kwargs=kwargs)
 
         results = []
         for conn in connections:
@@ -91,7 +111,7 @@ class Cluster(object):
                     elif retry == self.max_connection_retries - 1:
                         raise self.MaxRetriesExceededError(e)
                     else:
-                        conn = self._connections_for(attr, retry_for=conn.num, *args, **kwargs)[0]
+                        conn = self._connections_for(attr, retry_for=conn.num, args=args, kwargs=kwargs)[0]
                 else:
                     break
 
@@ -114,7 +134,7 @@ class Cluster(object):
         during all steps of the process. An example of this would be
         Redis pipelines.
         """
-        connections = self._connections_for('get_conn', *args, **kwargs)
+        connections = self._connections_for('get_conn', args=args, kwargs=kwargs)
 
         if len(connections) is 1:
             return connections[0]
@@ -124,8 +144,9 @@ class Cluster(object):
     def map(self, workers=None):
         return DistributedContextManager(self, workers)
 
-    def _connections_for(self, attr, *args, **kwargs):
-        return [self[n] for n in self.router.get_dbs(self, attr, *args, **kwargs)]
+    @routing_params
+    def _connections_for(self, attr, args, kwargs, **fkwargs):
+        return [self[n] for n in self.router.get_dbs(attr=attr, args=args, kwargs=kwargs, **fkwargs)]
 
 
 class CallProxy(object):
@@ -306,7 +327,12 @@ class DistributedConnection(object):
             command_map[cmd_ident] = command
 
             if self._cluster.router:
-                db_nums = self._cluster.router.get_dbs(self._cluster, command._attr, *command._args, **command._kwargs)
+                db_nums = self._cluster.router.get_dbs(
+                    cluster=self._cluster,
+                    attr=command._attr,
+                    args=command._args,
+                    kwargs=command._kwargs,
+                )
             else:
                 db_nums = self._cluster.keys()
 
