@@ -6,5 +6,4 @@ nydus.db.routers
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
-from .base import BaseRouter, RoundRobinRouter
-
+from .base import *
