@@ -24,7 +24,7 @@ class RedisTest(BaseTest):
         self.assertEquals(p.incr('RedisTest_with_cluster'), 1)
 
     def test_provides_retryable_exceptions(self):
-        self.assertEquals(Redis.retryable_exceptions, redis.exceptions)
+        self.assertEquals(Redis.retryable_exceptions, frozenset([redis.RedisError]))
 
     def test_provides_identifier(self):
         self.assertEquals(self.redis.identifier, str(self.redis.identifier))
@@ -53,7 +53,8 @@ class RedisTest(BaseTest):
         client.connect()
 
         self.assertEquals(RedisClient.call_count, 1)
-        RedisClient.assert_any_call(host='localhost', port=6379, db=0, socket_timeout=None)
+        RedisClient.assert_any_call(host='localhost', port=6379, db=0, socket_timeout=None,
+            password=None, unix_socket_path=None)
 
     @mock.patch('nydus.db.backends.redis.RedisClient')
     def test_map_does_pipeline(self, RedisClient):
