@@ -42,8 +42,12 @@ class TestThoonkPubsub(unittest2.TestCase):
     def tearDown(self):
         pass
 
+    def test_flush_db(self):
+        pubsub = self.get_cluster('nydus.db.routers.keyvalue.ConsistentHashingRouter')
+        pubsub.flushdb()
+
     def test_job_with_ConsistentHashingRouter(self):
-        pubsub = self.get_cluster('nydus.db.routers.redis.ConsistentHashingRouter')
+        pubsub = self.get_cluster('nydus.db.routers.keyvalue.ConsistentHashingRouter')
         job = pubsub.job("test1")
         jid = job.put("10")
 
@@ -58,7 +62,7 @@ class TestThoonkPubsub(unittest2.TestCase):
         self.assertTrue(jid_found)
 
     def test_job_with_RoundRobinRouter(self):
-        pubsub = self.get_cluster('nydus.db.routers.redis.RoundRobinRouter')
+        pubsub = self.get_cluster('nydus.db.routers.RoundRobinRouter')
 
         jobs = {}
         size = 20
@@ -85,7 +89,7 @@ class TestThoonkPubsub(unittest2.TestCase):
         self.assertEqual(len(jobs), 5)
 
         for x in range(len(pubsub)):
-            ps = pubsub.get_conn()
+            ps = pubsub.get_conn('testjob')
             jps = ps.job('testjob')
             self.assertEqual(jps.get_ids(), [])
 
